@@ -4,7 +4,7 @@ from .objectJSON import ObjectJSON
 
 class Boleto(ObjectJSON):
 
-    def __init__(self, nosso_numero,valor,numero_doc,dataemi,local_pagamento,prazo_vencimento):
+    def __init__(self, titulo):
         self.idintegracao = None
         self.situacao = None
         self.sacado = None
@@ -28,17 +28,17 @@ class Boleto(ObjectJSON):
         #self.CedenteConvenioNumero = None
         #self.cedente = None
         #self.titulo =None
-        self.TituloNossoNumero = str(nosso_numero)
-        self.TituloValor = str(valor)
-        self.TituloNumeroDocumento = str(numero_doc)
-        dataemissao = dataemi.strftime('%d/%m/%Y')
+        self.TituloNossoNumero = str(titulo['nosso_numero'])
+        self.TituloValor = str(titulo['valor'])
+        self.TituloNumeroDocumento = str(titulo['numero_doc'])
+        dataemissao = titulo['dataemi'].strftime('%d/%m/%Y')
         self.TituloDataEmissao = dataemissao
-        datavencimento = abs(dataemissao + prazo_vencimento)
+        datavencimento = abs(dataemissao + titulo['prazo_vencimento'])
         datavencimento = datavencimento.strftime('%d/%m/%Y')
         self.TituloDataVencimento = datavencimento
         self.TituloAceite = None
         self.TituloDocEspecie = None
-        self.TituloLocalPagamento = local_pagamento
+        self.TituloLocalPagamento = titulo['local_pagamento']
         self.juros = None
         #self.TituloCodigoJuros = None
         #self.TituloDataJuros = None
