@@ -1,6 +1,6 @@
 class Multa(object):
 
-    def __init__(self, cod_multa,data_multa,valor):
+    def __init__(self, multa):
         self.TituloCodigoMulta = None
         self.TituloDataMulta = None
         self.TituloValorMultaTaxa = None
